# Seald-CLI


## Usage

```
seald <command>

Commands:
  seald create-account [display-name] [email] [team-id]  Create an account
  seald list-team-invitations                            List team invitations
  seald join-team [team-id]                              Join team by id
  seald create-backup-key [output]                       Create a backup key
  seald load-backup-key [key]                            Load a backup key
  seald add-email [email]                                Add an email to the account
  seald encrypt [input..]                                Encrypt files  [aliases: encrypt-file]
  seald decrypt [input..]                                Decrypt a file  [aliases: decrypt-file]
  seald watch-encrypt [input] [output]                   Watch a folder and encrypt all files written to it into another folder
  seald add-recipients [input..]                         Authorize new recipients to read an encrypted file  [aliases: authorize-recipients]
  seald get-info [input]                                 Get information about an encrypted file
  seald revoke [input..]                                 Revoke recipients from reading an encrypted file

Options:
  --help          Show help  [boolean]
  --verbose, -v   Show logs.  [boolean]
  --silly         Show a _lot_ of logs.  [boolean]
  --silent        Show as little logs as possible.  [boolean]
  --api-url       URL of the Seald API server.  [string] [default: "https://api.seald.io/"]
  --hairless-url  URL of the Seald decrypt server.  [string] [default: "https://decrypt.seald.io/"]
  --proxy         URL of the proxy to use  [string] [default: null]
  --seald-dir     Path of the seald-cli directory.  [string] [default: "$HOME/.seald-cli"]
  --key-size      Size of the private keys to generate.  [number] [choices: 1024, 2048, 4096] [default: 4096]
  --version       Show version number  [boolean]

```

### `create-account`

```
seald create-account [--display-name <display_name>] [--email <email> [--email-validation <validation_token>] [--force] [--team-id <team_id>]]

Create an account.
Can only be used when no account has been created.
Team-id will be ignored is email is not specified

Options:
  --display-name, -d  Display Name of the account.  [default: "CLI Account"]
  --email, -e         Email address of the account.  [string] [default: null]
  --team-id, -t       UUID of the team you want to join. Will be ignored if email is not specified
  --email-validation  Automatic email validation token created by the admin  [string]
  --force, -f         If there is a warning, add email anyway without confirmation.  [boolean]
  --accept-licence    Assert that you have read and fully accept the licence agreement ( https://www.seald.io/licence-agreement ) and the privacy policy ( https://www.seald.io/privacy-policy ).  [boolean]

```

### `create-backup-key`

```
seald create-backup-key [--device-name <device_name>] [--output <output_file>]

Create a backup key.
Can only be used after account has been created.

Options:
  --output, -o       File to which to output the created key  [string] [default: "./seald-cli-backup.seald_key"]
  --device-name, -n  Name of the backup device  [string] [default: null]

```

### `load-backup-key`

```
seald load-backup-key --key <key_file> [--offline]

Load a backup key.
Can only be used when no account has been created.

Options:
  --key, -k  File from which to load the backup key.  [string] [required]
  --offline  Do not try loading account data online after loading the key.  [boolean]

```

### `add-email`

```
seald add-email --email <email> [--email-validation <validation_token>] [--force]

Add an email to the account.
Can only be used after account has been created.

Options:
  --email, -e         Email address of the account.  [string] [required]
  --email-validation  Automatic email validation token created by the admin  [string]
  --force, -f         If there is a warning, add email anyway without confirmation.  [boolean]

```

### `encrypt`

```
seald encrypt [--output <output_file>] [--recipients-ids <...recipients_ids>] [--recipients-emails <...recipients_emails>] [--recipients-emails-file <recipients_emails_file>] [--force-self] --input <files_to_encrypt..>

Encrypt a file.
Can only be used after account has been created.

Options:
  --input, -f, --file, --files, -i         Path of the file to encrypt.  [array] [required]
  --output, -o                             File to write the encrypted file to. Defaults to current directory, with the same name as the clear file + .shtml  [string]
  --recipients-ids, --uids                 IDs of the recipients to add.  [array] [default: []]
  --recipients-emails, --emails            Emails of the recipients to add.  [array] [default: []]
  --recipients-emails-file, --emails-file  path of the file containing the recipients' emails  [string]
  --force-self                             Do not ask for confirmation when you set no recipients other than yourself.  [boolean]
  --recursive, -r                          When given a directory, recursively encrypt all files inside.  [boolean]
  --retries                                When working on multiple files and there is an error, try this number of times  [number] [default: 3]
  --on-error                               When working on multiple files and there is an error, what is the behaviour  [string] [choices: "ignore", "warn", "fail"] [default: "fail"]
  --parallel                               When working on multiple files, run this number of tasks at the same time  [number] [default: 10]
  --remove, -R                             After encrypting a file, remove the clear one. When applied to a directory, also remove the directory.  [boolean]
  --remove-files                           After encrypting a file, remove the clear one. When applied to a directory, only remove the files inside.  [boolean]
  --on-same-file-name                      Behaviour when there is a conflict on the output file name  [string] [choices: "overwrite", "error", "increment", "skip"] [default: "error"]

```

### `decrypt`

```
seald decrypt-file --file <file_to_decrypt> [--output <output_directory>] [--offline-database <offline_database_path>] [--force] [--safe]

Decrypt a file.
Can only be used after account has been created.

Options:
  --input, -f, --file, --files, -i  Path of the file to decrypt.  [array] [required]
  --output, --output-dir, -o        Directory to write the decrypted file to. Defaults to current directory.  [string]
  --offline-database, -d            Offline backup of the database.  [string]
  --force, -f                       Decrypt anyway even if there is a warning, without confirmation. Only when decrypting single files. Always true when decrypting multiple files.  [array]
  --safe, -s                        Do not decrypt if there is a warning, without confirmation.
  --recursive, -r                   When given a directory, recursively decrypt all files inside.  [boolean]
  --retries                         When working on multiple files and there is an error, try this number of times  [number] [default: 3]
  --on-error                        When working on multiple files and there is an error, what is the behaviour  [string] [choices: "ignore", "warn", "fail"] [default: "fail"]
  --on-non-seald                    When working on multiple files and we encounter a non-seald file, what is the behaviour  [string] [choices: "ignore", "warn", "fail"] [default: "warn"]
  --parallel                        When working on multiple files, run this number of tasks at the same time  [number] [default: 10]
  --remove, -R                      After decrypting a file, remove the encrypted one. When applied to a directory, also remove the directory.  [boolean]
  --remove-files                    After decrypting a file, remove the encrypted one. When applied to a directory, only remove the files inside.  [boolean]

```

### `watch-encrypt`

```
seald watch-encrypt --input <input_folder_path> --output <output_folder_path> [--remove] [--existing] [--recipients-ids <...recipients_ids>] [--recipients-emails <...recipients_emails>] [--recipients-emails-file <recipients_emails_file>]

Watch a folder and encrypt all files written to it into another folder.
Can only be used after account has been created.

Options:
  --input, -i                              Path of the folder to watch.  [string] [required]
  --output, -o                             Path of the folder to which to write the encrypted files.  [string] [required]
  --remove, -r                             Remove cleartext files once encrypted.  [boolean]
  --existing, -e                           Also encrypt already existing files.  [boolean]
  --retries                                When there is a file-system error, try this number of times (other errors will always be retried)  [number] [default: 3]
  --recipients-ids, --uids                 IDs of the recipients to add.  [array] [default: []]
  --recipients-emails, --emails            Emails of the recipients to add.  [array] [default: []]
  --recipients-emails-file, --emails-file  Path of the file containing the recipients' emails  [string]
  --on-same-file-name                      Behaviour when there is a conflict on the output file name  [string] [choices: "overwrite", "error", "increment", "skip"] [default: "error"]

```

### `add-recipients`

```
seald add-recipients --file <file> [--recipients-ids <...recipients_ids>] [--recipients-emails <...recipients_emails>] [--recipients-emails-file <recipients_emails_file>] [--recursive]

Authorize new recipients to read an encrypted file

Options:
  --help                                   Show help  [boolean]
  --verbose, -v                            Show logs.  [boolean]
  --silly                                  Show a _lot_ of logs.  [boolean]
  --silent                                 Show as little logs as possible.  [boolean]
  --api-url                                URL of the Seald API server.  [string] [default: "https://api.seald.io/"]
  --hairless-url                           URL of the Seald decrypt server.  [string] [default: "https://decrypt.seald.io/"]
  --proxy                                  URL of the proxy to use  [string] [default: null]
  --seald-dir                              Path of the seald-cli directory.  [string] [default: "$HOME/.seald-cli"]
  --key-size                               Size of the private keys to generate.  [number] [choices: 1024, 2048, 4096] [default: 4096]
  --version                                Show version number  [boolean]
  --input, -f, --file, --files, -i         Path of the encrypted file or files.  [array] [required]
  --recipients-ids, --uids                 IDs of the recipients to add.  [array] [default: []]
  --recipients-emails, --emails            Emails of the recipients to add.  [array] [default: []]
  --recipients-emails-file, --emails-file  path of the file containing the recipients' emails  [string]
  --recursive, -r                          When given a directory, recursively authorize all files inside.  [boolean]
  --retries                                When working on multiple files and there is an error, try this number of times  [number] [default: 3]
  --on-error                               When working on multiple files and there is an error, what is the behaviour  [string] [choices: "ignore", "warn", "fail"] [default: "fail"]
  --on-non-seald                           When working on multiple files and we encounter a non-seald file, what is the behaviour  [string] [choices: "ignore", "warn", "fail"] [default: "warn"]
  --parallel                               When working on multiple files, run this number of tasks at the same time  [number] [default: 10]

```

### `get-info`

```
seald get-info --file <file_path>

Options:
  --help                   Show help  [boolean]
  --verbose, -v            Show logs.  [boolean]
  --silly                  Show a _lot_ of logs.  [boolean]
  --silent                 Show as little logs as possible.  [boolean]
  --api-url                URL of the Seald API server.  [string] [default: "https://api.seald.io/"]
  --hairless-url           URL of the Seald decrypt server.  [string] [default: "https://decrypt.seald.io/"]
  --proxy                  URL of the proxy to use  [string] [default: null]
  --seald-dir              Path of the seald-cli directory.  [string] [default: "$HOME/.seald-cli"]
  --key-size               Size of the private keys to generate.  [number] [choices: 1024, 2048, 4096] [default: 4096]
  --version                Show version number  [boolean]
  --input, -f, --file, -i  [string]

```

### `revoke`

```
seald revoke --file <...files_path> [--revoke-emails <...emails_to_revoke>] [--revoke-emails-file <emails_list_to_revoke>] [--revoke-ids <...ids_to_revoke>]

Options:
  --help                               Show help  [boolean]
  --verbose, -v                        Show logs.  [boolean]
  --silly                              Show a _lot_ of logs.  [boolean]
  --silent                             Show as little logs as possible.  [boolean]
  --api-url                            URL of the Seald API server.  [string] [default: "https://api.seald.io/"]
  --hairless-url                       URL of the Seald decrypt server.  [string] [default: "https://decrypt.seald.io/"]
  --proxy                              URL of the proxy to use  [string] [default: null]
  --seald-dir                          Path of the seald-cli directory.  [string] [default: "$HOME/.seald-cli"]
  --key-size                           Size of the private keys to generate.  [number] [choices: 1024, 2048, 4096] [default: 4096]
  --version                            Show version number  [boolean]
  --input, -f, --file, --files, -i     Path of the encrypted file.  [array] [required]
  --revoke-all, --all                  Revoke all recipients.  [boolean]
  --revoke-others, --others            Revoke everyone except me.  [boolean]
  --revoke-emails, --emails            Emails of the recipients to revoke.  [array]
  --revoke-emails-file, --emails-file  File containing emails of the recipients to revoke.  [string]
  --revoke-ids, --uids                 IDs of the recipients to revoke.  [array]
  --recursive, -r                      When given a directory, recursively revoke all files inside.  [boolean]
  --retries                            When working on multiple files and there is an error, try this number of times  [number] [default: 3]
  --on-error                           When working on multiple files and there is an error, what is the behaviour  [string] [choices: "ignore", "warn", "fail"] [default: "fail"]
  --on-non-seald                       When working on multiple files and we encounter a non-seald file, what is the behaviour  [string] [choices: "ignore", "warn", "fail"] [default: "warn"]
  --parallel                           When working on multiple files, run this number of tasks at the same time  [number] [default: 10]

```
